<template>
  <div class="app-container">
    <div style="display: flex;justify-content: space-between;margin-bottom: 10px">
      <el-form :inline="true" style="display: flex;align-items: center;flex-wrap: wrap;" >
        <el-form-item>
          <el-button
              type="primary"
              plain
              icon="Plus"
              @click="addProject('add',{})"
          >
            新增
          </el-button>
        </el-form-item>
        <el-form-item label="姓名：" >
          <el-input v-model="data.queryParams.filter.companyName" placeholder="请输入姓名"></el-input>
        </el-form-item>
        <el-form-item >
          <el-button
              type="primary"
              @click="getList"
          >查询</el-button>
          <el-button
              type="primary"
              plain
              @click="reset"
          >重置</el-button>
        </el-form-item>
      </el-form>
    </div>
    <!-- 表格数据 -->
    <el-table v-loading="loading" :data="dataList" :border="true">
      <el-table-column label="序号" type="index" align="center" width="80" />
      <el-table-column label="姓名" prop="personName" align="center"  />
      <el-table-column label="人员类型" prop="personType" align="center" >
        <template #default="scope">
          <span>{{scope.row.personType == 1 ? '法定代表人' : scope.row.personType == 2?'主要负责人':scope.row.personType == 3?'安全负责人':scope.row.personType == 4?'保管员':scope.row.personType == 5?'守护员':''}}</span>

        </template>
      </el-table-column>
      <el-table-column label="联系方式" prop="mb" align="center" />
      <el-table-column label="创建人" prop="createBy" align="center" />
      <el-table-column label="修改人" prop="updateBy" align="center" />
      <el-table-column label="创建时间" prop="createDate" align="center" width="110" />
      <el-table-column label="修改时间" prop="updateDate" align="center"  width="110"/>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" width="250" >
        <template #default="scope">
          <el-button link type="primary" @click="addProject('edit',scope.row)">编辑</el-button>
          <el-button link type="danger" @click="handleDelete(scope.row)">删除</el-button>
        </template>
      </el-table-column>
    </el-table>
    <pagination
        v-show="total > 0"
        :total="total"
        v-model:page="queryParams.pageIndex"
        v-model:limit="queryParams.pageSize"
        @pagination="getList"
    />
    <peopleDialog ref="dialogRef" @getList="getList"></peopleDialog>
  </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, onUnmounted, reactive, ref, toRefs} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import peopleDialog from './components/peopleDialog.vue'
import Cookies from "js-cookie";
import {delTemplate, getTemplate} from "@/api/signAgreement/template";
import {delPeople, getPeople} from "@/api/company/people";
const { proxy } = getCurrentInstance();
const loading = ref(false);
const dialogRef = ref();
const createSignRef = ref();
const data = reactive({
  queryParams: {
    pageIndex: 1,
    pageSize: 10,
    filter: {
      companyName: '',
      companyCode: ''
    }
  },
  total: 0,
  dataList: []
});

const { queryParams, total, dataList } = toRefs(data);
const classHourRef = ref();
onMounted(()=>{
  const info = JSON.parse(Cookies.get('userInfo'))
  data.queryParams.filter.companyCode = info.companynumber
  getList()
})

onUnmounted(()=>{

})

const addProject = (type,value) => {
  dialogRef.value.openDialog(type,value)
}
const getList = async () => {
  loading.value = true
  const res = await getPeople(data.queryParams)
  if(res.code == 200){
    data.dataList = res.result.records
    data.total = res.result.total
  }else{
    ElMessage.warning(res.message)
  }
  loading.value = false
}

/** 重置新增的表单以及其他数据  */
function reset() {
  data.queryParams = {
    pageIndex: 1,
    pageSize: 10,
    filter: {
      companyName: '',
      companyCode: ''
    }
  }
  getList()
}
const handleDelete = (val) => {
  ElMessageBox.confirm(
      '确定删除此条数据？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then( async() => {
        const param = {
         id:val.id
        }
        const res = await delPeople(param)
        if(res.code == 200){
          ElMessage.success('数据删除成功')
          await getList()
        }else{
          ElMessage.warning(res.message)
        }
      })
}



const getRowKeys = (row) => {
  return row.name
}
</script>
